@@ -1,10 +1,10 @@
-/* $Id: chess.h,v 1.38 2002/06/14 17:32:57 bergo Exp $ */
+/* $Id: chess.h,v 1.46 2007/01/08 21:46:13 bergo Exp $ */
 
 /*
 
     eboard - chess client
     http://eboard.sourceforge.net
-    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
+    Copyright (C) 2000-2007 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -33,6 +33,7 @@
 #include "position.h"
 #include "board.h"
 #include "movelist.h"
+#include "clock.h"
 #include <stdio.h>
 #include "stl.h"
 
@@ -67,18 +68,21 @@ class PGNheader {
   friend ostream &operator<<(ostream &s, PGNheader h);
 };
 
+ostream &operator<<(ostream &s, PGNheader h);
+
 class ChessGame : public MoveListListener {
  public:
   ChessGame();
   ChessGame(int _number,int _tyme,int _inc, int _rated,variant _variant,
 	    char *p1,char *p2);
   ChessGame(ChessGame *src);
-  ~ChessGame();
+  virtual ~ChessGame();
 
   int operator==(int gnum);
 
   void updatePosition(Position &p,int movenum,int blacktomove,
-		      int wclock,int bclock,char *infoline,bool sndflag=false);
+		      int wclock,int bclock,char *infoline,
+		      bool sndflag=false);
   void updateStock();
   void updateGame(list<Position> &gamedata);
   void flipHint(int flip);
@@ -92,6 +96,8 @@ class ChessGame : public MoveListListener {
   void enableMoving(bool flag);
   int  isOver();
 
+  void incrementActiveClock(int secs);
+
   char *getPlayerString(int index);
   char *getEndReason();
   GameResult getResult();
@@ -115,7 +121,7 @@ class ChessGame : public MoveListListener {
 
   void retreat(int nmoves);
   static void LoadPGN(char *filename);
-  static bool ParsePgnGame(istream &f,
+  static bool ParsePgnGame(zifstream &f,
 			   char * filename,
 			   bool indexonly, 
 			   int gameid,
@@ -137,17 +143,16 @@ class ChessGame : public MoveListListener {
   void setSideHint(bool white);
 
   static const char *variantName(variant v);
-  static variant variantFromName(char *p);
+  static variant variantFromName(const char *p);
 
-  int     GameNumber;
-  int     STime;
-  int     Inc;
-  int     Rated;
-  variant Variant;
-  char    PlayerName[2][64];
-  char    Rating[2][32];
-  piece   MyColor;
-  int     StopClock; // for examined games
+  int         GameNumber;
+  int         Rated;
+  variant     Variant;
+  char        PlayerName[2][64];
+  char        Rating[2][32];
+  piece       MyColor;
+  int         StopClock; // for examined games
+  TimeControl timecontrol;
 
   bool    LocalEdit;
 
@@ -169,6 +174,9 @@ class ChessGame : public MoveListListener {
  private:
   void showResult();
   void fixExamineZigZag(Position &suspect);
+  void updateClockAndInfo(int wclock, int bclock,int blacktomove, 
+			  char *infoline, 
+			  bool sndflag);
 
   list<Position> moves;
   list<Position>::iterator cursor;
@@ -185,6 +193,11 @@ class ChessGame : public MoveListListener {
   GameResult result;
   char ereason[128];
 
+  static bool             GlyphsInited;
+  static vector<string *> Glyphs;
+  static void initGlyphs();
+  static void failGlyphs();
+
 };
 
 class PGNEditInfoDialog : public ModalDialog {
@@ -206,4 +219,12 @@ class PGNEditInfoDialog : public ModalDialog {
 			       GdkEventButton *eb,gpointer data);
 };
 
+void pgnedit_set(GtkWidget *w, gpointer data);
+void pgnedit_del(GtkWidget *w, gpointer data);
+void pgnedit_rowsel(GtkCList *w, gint row, gint col,
+		    GdkEventButton *eb,gpointer data);
+void pgnedit_rowunsel(GtkCList *w, gint row, gint col,
+		      GdkEventButton *eb,gpointer data);
+
+
 #endif
