@@ -1,10 +1,10 @@
-/* $Id: global.h,v 1.72 2003/07/03 19:47:53 bergo Exp $ */
+/* $Id: global.h,v 1.81 2007/01/20 23:28:57 bergo Exp $ */
 
 /*
 
     eboard - chess client
     http://eboard.sourceforge.net
-    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
+    Copyright (C) 2000-2007 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -97,6 +97,8 @@ class ZombieHunter {
   vector<SigChildHandler *> handlers;
 };
 
+void zh_sigchild_handler(int sig);
+
 class IcsChannel {
  public:
   IcsChannel(char *s); // s like "49\tmamer tourneys\n"
@@ -117,6 +119,7 @@ class ChannelSplitter : public SigChildHandler
   void channelPageDown(int ch);
 
   void ZombieNotification(int pid);
+  void updateFont();
 
  protected:
   void updateChannelScrollBacks();
@@ -158,6 +161,7 @@ class WindowGeometry {
   WindowGeometry();
 
   void read(tstring &t);
+  void print();
 
   void retrieve(GtkWidget *w);
   bool isNull();
@@ -168,6 +172,7 @@ class WindowGeometry {
 class Desktop {
  public:
 
+  Desktop();
   void clear();
 
   void read(tstring &t);
@@ -234,6 +239,8 @@ class Global : public ChannelSplitter
   void agentBroadcast(char *z);
   int  receiveAgentLine(char *dest,int limit);
 
+  bool effectiveLegalityChecking();
+
   /* issue sound events */
   void opponentMoved();
   void drawOffered();
@@ -257,8 +264,6 @@ class Global : public ChannelSplitter
 
   Notebook * getNotebook();
 
-  GdkFont *loadFont(EboardFont i);
-
   void setPieceSet(string &filename,bool chgPieces,bool chgSquares);
   void respawnPieceSet();
   void addPieceClient(PieceChangeListener *pcl);
@@ -299,6 +304,7 @@ class Global : public ChannelSplitter
   GtkWidget          *toplevelwidget;
   BugPane            *bugpane;
   IONotificationInterface *iowatcher;
+  JoystickListener   *joycapture;
 
   StringCollection   annotator;
   SoundSlave         sndslave;
@@ -355,6 +361,17 @@ class Global : public ChannelSplitter
   int IcsAllObPlayed;
   int IcsAllObObserved;
 
+  int SeekTableSortCol;
+  int SeekTableSortDir;
+
+  int JSCursorAxis;
+  int JSBrowseAxis;
+  int JSMoveButton;
+  int JSNextTabButton;
+  int JSPrevTabButton;
+  int JSMode;
+  int JSSpeed;
+
   char P2PName[64];
 
   TerminalColor Colors;
@@ -387,6 +404,8 @@ class Global : public ChannelSplitter
 
   string ConsoleReply;
 
+  int JoystickFD;
+
  private:
   int createDir(char *z);
   void renumberGame(ChessGame *cg,int id);
