@@ -1,10 +1,10 @@
-/* $Id: sound.h,v 1.10 2003/01/12 19:26:20 bergo Exp $ */
+/* $Id: sound.h,v 1.11 2007/01/01 18:29:03 bergo Exp $ */
 
 /*
 
     eboard - chess client
     http://eboard.sourceforge.net
-    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
+    Copyright (C) 2000-2007 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -94,6 +94,11 @@ class SoundEventDialog : public ModalDialog {
   friend void snddlg_picktheme(GtkMenuItem *w,gpointer data);
 };
 
+void snddlg_ok(GtkWidget *w,gpointer data);
+void snddlg_test(GtkWidget *w,gpointer data);
+void snddlg_browse(GtkWidget *w,gpointer data);
+void snddlg_picktheme(GtkMenuItem *w,gpointer data);
+
 class SoundSlave {
  public:
   SoundSlave();
